import { useReducer } from 'react';
import { SearchBar } from '../components/SearchBar/index';
import { Filters } from '../components/Filters/index';
import { RecipeGrid } from '../components/RecipeGrid/index';
import { RecipeDetails } from '../components/RecipeDetails/index';
import { useRecipes } from '../hooks/useRecipe';
import { initialState, recipeReducer } from '../store/RecipeStore';
import '../components/RecipeFinder.css';

export const RecipeFinder = () => {
    const [state, dispatch] = useReducer(recipeReducer, initialState);
    const { data: recipes, isLoading, error } = useRecipes(
        state.searchQuery,
        state.filters
    );

    const handleSearch = (query) => {
        dispatch({ type: 'SET_SEARCH', payload: query });
    };

    const handleFilterChange = (field, value) => {
        dispatch({ type: 'SET_FILTER', field, payload: value });
    };

    const handleRecipeClick = (recipe) => {
        console.log("Recipe clicked:", recipe); 
        dispatch({ type: 'SET_SELECTED_RECIPE', payload: recipe });
    };
    
    if (error) return <div className="error">Error loading recipes</div>


  return (
    <div className="container">
        <h3 className="title">Assignment 4</h3>
        <h1 className="title">Recipe Finder</h1>
        <div className="filters-section">
            <SearchBar onSearch={handleSearch} />
            <Filters filters={state.filters} onFilterChange={handleFilterChange} />
        </div>
        {isLoading ? (
            <div className="loading">Loading recipes...</div>
        ):(
            <RecipeGrid recipes={recipes} onRecipeClick={handleRecipeClick} />
        )}

        {state.selectedRecipe && (
            <RecipeDetails
            recipe={state.selectedRecipe}
            onClose={() => dispatch({ type: 'SET_SELECTED_RECIPE', payload: null })}
            />
        )}
    </div>
  );
};